Skip to contents

Used to draw line plot for comparing three methods (2 RMST and log-rank test) under different scenario Input is the dataframe of 3m_comparison output. ** The order of variable is fixed **

Usage

compare_line_plot(data, var_name)

Arguments

data

Please make sure the data structure is the same as the example on Github ipynb file

var_name

The variable name shown on X-axis of plots