Skip to contents

This function sets the number of cores to be used for parallel processing. If the requested number exceeds the available cores, it will default to the 16 cores.

Usage

set_cores(n = 16)

Arguments

n

Integer specifying the number of cores. Default is 16.