Plotting the comparison of 3 methods
compare_line_plot.RdUsed to draw line plot for comparing three methods (2 RMST and log-rank test) under different scenario Input is the dataframe of 3m_comparison output. ** The order of variable is fixed **
compare_line_plot.RdUsed to draw line plot for comparing three methods (2 RMST and log-rank test) under different scenario Input is the dataframe of 3m_comparison output. ** The order of variable is fixed **